Example Scripts
===============

This directory contains example scripts that illustrate the use of
pyvo.  Be sure that that pyvo (e.g. the parent of this directory) is
in your PYTHONPATH.  (And don't forget: these require network access,
and an unreliable or slow network may produce poor results.)

ex_casA_image_cat.py
   discovers archives that may have x-ray images and then queries
   those archives to find what x-ray images they have of CasA; the
   list of images are saved to a CSV file.

ex_get_cutouts.py
   downloads cut-out images for a list of source from the NVSS
   survey. 




